@@ -1074,7 +1074,7 @@ class PartitionDistributive(Distributive):
 
     def formatAllPartitions(self):
         """Format all partitions"""
-        FS, DEV, NEEDFORMAT, NEWID, PARTTABLE = 0, 1, 2, 3, 4
+        FS, DEV, NEEDFORMAT, NEWID, PARTTABLE, MP = 0, 1, 2, 3, 4, 5
         # get all information to matrix
         dataPartitions = zip(self.multipartition.getFileSystems() + \
                              [self.fileSystem],
@@ -1085,14 +1085,16 @@ class PartitionDistributive(Distributive):
                              self.multipartition.getSystemId() + \
                              [self.systemId],
                              self.multipartition.getPartitionTable() + \
-                             [self.partitionTable])
+                             [self.partitionTable],
+                             self.multipartition.getMountPoints() + \
+                             ["/"])
         # get partition which need format
-        formatPartitions = map(lambda x: (x[FS], x[DEV], x[NEWID]),
+        formatPartitions = map(lambda x: (x[FS], x[DEV], x[NEWID], x[MP]),
                                filter(
                                    lambda x: x[NEEDFORMAT] and x[FS] != "bind",
                                    dataPartitions))
         # format all get partition
-        for fileSystem, dev, newID in formatPartitions:
+        for fileSystem, dev, newID, mp in formatPartitions:
             if fileSystem == "swap":
                 self.formatSwapPartition(dev)
             else:
@@ -1102,7 +1104,11 @@ class PartitionDistributive(Distributive):
                     self.formatPartition(dev, format=fileSystem,
                                          label=self.rootLabel)
                 else:
-                    self.formatPartition(dev, format=fileSystem)
+                    if mp == '/var/calculate':
+                        self.formatPartition(dev, format=fileSystem,
+                                             label="Calculate")
+                    else:
+                        self.formatPartition(dev, format=fileSystem)
         # change system id for partitions
         changeidPartitions = map(lambda x: (x[NEWID], x[DEV], x[PARTTABLE]),
                                  filter(lambda x: x[NEWID],
