@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -26,11 +26,10 @@ from calculate.core.server.func import MethodsInterface
 from calculate.lib.utils.files import (pathJoin,
                                        isMount, process, listDirectory,
                                        checkUtils, readFile, find, copyWithPath,
-                                       readLinesFile)
+                                       readLinesFile, getProgPath)
 from calculate.lib.utils.device import (detectDeviceForPartition,
                                         getUdevDeviceInfo, refreshLVM,
                                         refreshUdev, countPartitions)
-from calculate.lib.cl_vars_share import varsShare
 from datavars import DataVarsInstall
 from calculate.install.variables.autopartition import AutoPartition
 
@@ -38,12 +37,14 @@ from distr import DistributiveError
 from subprocess import Popen, PIPE, STDOUT
 from itertools import *
 
+
 class InstallError(Exception):
     """Installation Error"""
 
+
 from migrate_users import migrate
 
-from calculate.lib.cl_lang import setLocalTranslate,getLazyLocalTranslate, _
+from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
@@ -59,7 +60,7 @@ class Install(MethodsInterface):
         # refresh information about device in udevadm info
         refreshUdev()
 
-    def initVars(self,datavars=None):
+    def initVars(self, datavars=None):
         """Primary initialization of variables"""
         if not datavars:
             self.clVars = DataVarsInstall()
@@ -88,20 +89,20 @@ class Install(MethodsInterface):
                 self.installLegacyGrubBootloader(target_distr)
         return True
 
-    def setActivePartition(self,partition):
+    def setActivePartition(self, partition):
         """
         Установка активного раздела для dos и gpt таблицы разделов
         """
         device_name = detectDeviceForPartition(partition)
         if device_name is None:
             raise DistributiveError(
-                _("Failed to determine the parent device for %s")%partition)
+                _("Failed to determine the parent device for %s") % partition)
         # device hasn't any partition
         elif device_name == "":
             return True
         fdisk_cmd, gdisk_cmd, parted_cmd = checkUtils('/sbin/fdisk',
-                                                         '/usr/sbin/gdisk',
-                                                         '/usr/sbin/parted')
+                                                      '/usr/sbin/gdisk',
+                                                      '/usr/sbin/parted')
 
         disk = self.clVars.Select('os_install_disk_parent',
                                   where='os_install_disk_dev', eq=partition,
@@ -123,31 +124,36 @@ class Install(MethodsInterface):
         if partition_table == "dos":
             fdisk = process(fdisk_cmd, "-l", device_name)
             DEVICENUM, AFLAG = 0, 1
-            change_active = \
-                map(lambda x:x[DEVICENUM],
-                filter(lambda x:(x[DEVICENUM] != partition_number and
-                                x[AFLAG] == "*" or
-                                x[DEVICENUM] == partition_number and
-                                not x[AFLAG] == "*"),
-                list(map(lambda x: [str(x[0]), x[1][1].strip()],
-                # enumerate partitions
-                enumerate(filter(None,
-                map(lambda x: x.split()[:2],
-                # drop string before information about partitions
-                dropwhile(lambda x: not x.lstrip().startswith("Device"),
-                fdisk.readlines()))))))[1:]))
+            change_active = map(
+                lambda x: x[DEVICENUM],
+                filter(
+                    lambda x: (x[DEVICENUM] != partition_number and
+                               x[AFLAG] == "*" or
+                               x[DEVICENUM] == partition_number and
+                               not x[AFLAG] == "*"),
+                    list(map(
+                        lambda x: [str(x[0]), x[1][1].strip()],
+                        # enumerate partitions
+                        enumerate(filter(None, map(
+                            lambda x: x.split()[:2],
+                            # drop string before information about partitions
+                            dropwhile(
+                                lambda x: not x.lstrip().startswith(
+                                    "Device"),
+                                fdisk.readlines()))))))[1:]))
         else:
-            parted = process(parted_cmd, "-m",device_name,"print")
-            DEVICENUM,FLAGS = 0,6
-            change_active = \
-                map(lambda x:x[DEVICENUM],
-                filter(lambda x:x[DEVICENUM] != partition_number and \
-                                boot_flag in x[FLAGS].strip(';').split(', ') or \
-                                x[DEVICENUM] == partition_number and \
-                                not boot_flag in x[FLAGS].strip(';').split(', '),
-                filter(lambda x:len(x)>=7,
-                map(lambda x:x.split(':'),
-                parted.readlines()[2:]))))
+            parted = process(parted_cmd, "-m", device_name, "print")
+            DEVICENUM, FLAGS = 0, 6
+            change_active = map(
+                lambda x: x[DEVICENUM], filter(
+                    lambda x: (x[DEVICENUM] != partition_number and
+                               boot_flag in x[FLAGS].strip(';').split(', ') or
+                               x[DEVICENUM] == partition_number and
+                               boot_flag not in
+                               x[FLAGS].strip(';').split(', ')),
+                    filter(lambda x: len(x) >= 7,
+                           map(lambda x: x.split(':'),
+                               parted.readlines()[2:]))))
         if not change_active:
             return True
         if partition_table == "dos":
@@ -179,7 +185,7 @@ class Install(MethodsInterface):
             _("Failed to find partition %s after changing the activity") %
             partition)
 
-    def installSyslinuxBootloader(self,target):
+    def installSyslinuxBootloader(self, target):
         """
         Установить syslinux загрузчик (используется для flash)
         """
@@ -215,8 +221,8 @@ class Install(MethodsInterface):
         process("sync").success()
         # если установка GRUB2 производится на текущую систему
         # загруженную в builder режиме
-        if self.clVars.Get('os_install_scratch') == "on" and \
-                        self.clVars.Get('cl_action') != "system":
+        if (self.clVars.Get('os_install_scratch') == "on" and
+                    self.clVars.Get('cl_action') != "system"):
             prefix_boot = "/mnt/scratch"
         else:
             prefix_boot = "/"
@@ -290,8 +296,8 @@ class Install(MethodsInterface):
         # если среди загрузочных записей отсутствует запись
         # calculate и dmesg содержит сообщение об ошибке efivars -
         # запись создать не удалось
-        efi_boot_mgr = varsShare().getProgPath('/usr/sbin/efibootmgr')
-        dmesg = varsShare().getProgPath('/bin/dmesg')
+        efi_boot_mgr = getProgPath('/usr/sbin/efibootmgr')
+        dmesg = getProgPath('/bin/dmesg')
         if efi_boot_mgr and dmesg:
             if not re.search('Boot.*calculate',
                              process(efi_boot_mgr).read(), re.M) and \
@@ -300,13 +306,13 @@ class Install(MethodsInterface):
                 raise DistributiveError(
                     _("Failed to create the UEFI boot record"))
 
-    def installLegacyGrubBootloader(self,target):
+    def installLegacyGrubBootloader(self, target):
         """
         Install legecy grub boot loader
 
         Perform grub installation to disk, which has root partition
         """
-        cmd_grub = varsShare().getProgPath('/sbin/grub')
+        cmd_grub = getProgPath('/sbin/grub')
         if not cmd_grub:
             raise DistributiveError(_("Failed to install the bootloader"))
         grub_process = process(
@@ -401,7 +407,7 @@ class Install(MethodsInterface):
                 (getUdevDeviceInfo(name=root_dev).get('DEVPATH', '')))
             if path.exists(scheduler_path):
                 open(scheduler_path, 'w').write(scheduler)
-        except:
+        except Exception:
             raise InstallError(_("Unable to change the I/O scheduler"))
         return True
 
@@ -420,7 +426,7 @@ class Install(MethodsInterface):
                          lvm_vgname, bios_grub, bios_grub_size)
         return True
 
-    def format(self,target):
+    def format(self, target):
         """
         Форматировать разделы для 'target' дистрибутива
         """
@@ -509,7 +515,8 @@ class Install(MethodsInterface):
             try:
                 os.rmdir(mount_dir)
             except (OSError, IOError):
-                self.printWARNING(_("Unable to remove directory %s") % mount_dir)
+                self.printWARNING(
+                    _("Unable to remove directory %s") % mount_dir)
                 return False
         return res
 
