@@ -34,8 +34,10 @@ class _shareData(object):
 
     def getDataInFile(self, fileName='', lenData=7):
         """Get data list from file"""
-        return filter(lambda x: len(x) == lenData,
-                      map(lambda x: x.rstrip().split(":"), open(fileName)))
+        return map(lambda x: x[:lenData],
+                   filter(lambda x: len(x) >= lenData,
+                          map(lambda x: x.rstrip().split(":"),
+                              open(fileName))))
 
 
 class migrateGroups(_shareData):
