@@ -27,7 +27,8 @@ from calculate.lib.utils.common import (getVideoFromXorgLog,
                                         getAvailableVideo, getValueFromCmdLine,
                                         getCompositeFromXorgconf,
                                         getVideoFromModules,
-                                        getVideoFromVendor, getInstalledVideo)
+                                        getVideoFromVendor, getInstalledVideo,
+                                        CmdlineParams)
 from calculate.install.distr import DistributiveError
 import fcntl
 import struct
@@ -45,6 +46,8 @@ class VideoVariable(Variable):
     default_video = "default"
     driver_names = {'nvidia': _("NVidia proprietary video driver"),
                     'fglrx': _("ATI proprietary video driver"),
+                    #'amdgpu': _("ATI open source video driver with "
+                    #            "proprietary user-space"),
                     'intel': _("Intel video driver"),
                     'radeon': _("ATI open source video driver"),
                     'nouveau': _("NVidia open source video driver"),
@@ -58,7 +61,8 @@ class VideoVariable(Variable):
         if self.Get('os_install_root_type') == 'flash':
             return \
                 _("Video configuration unavailable for Flash install")
-        if self.Get('os_install_x11_server_set') == 'off' and self.xorg_need:
+        if (self.Get('install.os_install_x11_server_set') == 'off' and
+                self.xorg_need):
             return \
                 _("This distribution does not provide a Xorg server")
         return ""
@@ -124,6 +128,7 @@ class VariableOsInstallX11VideoAvailable(VideoVariable):
     Get available (already installed or installable drivers
     """
     type = "list"
+    #supported = ["nvidia", "fglrx", "amdgpu", "nouveau", "intel", "radeon"]
     supported = ["nvidia", "fglrx", "nouveau", "intel", "radeon"]
 
     def get(self):
@@ -150,7 +155,7 @@ class VariableOsX11KmsVideoDrv(ReadonlyVariable):
     Список KMS драйверов
     """
     type = "list"
-    value = ["radeon", "intel", "nouveau"]
+    value = ["radeon", "intel", "nouveau"] #, "amdgpu"]
 
 
 class VariableOsInstallX11VideoDrv(VideoVariable):
@@ -265,10 +270,12 @@ class VariableOsInstallX11Composite(VideoVariable):
 
     def get(self):
         """On/off composite"""
-        defaultCompositeOn = ("nvidia", "intel", "fglrx",
+        defaultCompositeOn = ("nvidia", "intel", "fglrx", # "amdgpu",
                               "nouveau", "radeon", "default")
-        composite = getValueFromCmdLine("calculate", 5)
-        videodrv = getValueFromCmdLine("calculate", 4)
+        composite = getValueFromCmdLine(CmdlineParams.Calculate,
+                                        CmdlineParams.Composite)
+        videodrv = getValueFromCmdLine(CmdlineParams.Calculate,
+                                       CmdlineParams.Video)
         if videodrv != "auto":
             composite = {'nocomposite': 'off',
                          'off': 'off',
