@@ -24,7 +24,8 @@ from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
 from calculate.install.fs_manager import FileSystemManager
 from calculate.lib.utils.files import (readFile, getProgPath, process,
                                        readLinesFile)
-from calculate.lib.utils.common import getPasswdUsers, getUserGroups, getGroups
+from calculate.lib.utils.common import getPasswdUsers, getUserGroups, getGroups, \
+    CmdlineParams
 from calculate.lib.utils.common import getValueFromConfig, getValueFromCmdLine
 from calculate.lib.utils.common import getUserPrimaryGroup
 from calculate.lib.utils.portage import isPkgInstalled
@@ -324,8 +325,10 @@ class VariableClAutologin(UserHelper, Variable):
 
     def get(self):
         # autologin enable for livecd and all install type CMC
-        cmdDomainSet = (getValueFromCmdLine("calculate", "domain_pw") or
-                        getValueFromCmdLine("calculate", "domain") or "")
+        cmdDomainSet = (getValueFromCmdLine(
+            "calculate", CmdlineParams.DomainPassword) or
+                        getValueFromCmdLine(
+                            "calculate", CmdlineParams.Domain) or "")
         if (not cmdDomainSet and
                     self.Get('os_install_root_type') == "livecd") or \
                         self.Get('os_install_linux_shortname') == "CMC":
